@@ -3,16 +3,17 @@
 #
 # This source code is licensed under the BSD-style license found in the
 # LICENSE file in the root directory of this source tree.
-
+import asyncio
+import shlex
+import subprocess
 import datetime
 import functools
 import json
 import os
-import shlex
 import shutil
-import subprocess
 import sys
 import traceback
+from _decimal import Decimal
 from http import HTTPStatus
 from typing import Any, Awaitable, Callable, List, Optional
 
@@ -166,7 +167,7 @@ class GraderBaseHandler(SessionMixin, web.RequestHandler):
         if repo_type == "source" or repo_type == "release" or repo_type == "edit":
             path = os.path.join(assignment_path, repo_type)
             if repo_type == "edit":
-                path = os.path.join(path,str(submission.id))
+                path = os.path.join(path, str(submission.id))
                 self.log.info(path)
         elif repo_type in ["autograde", "feedback"]:
             type_path = os.path.join(assignment_path, repo_type, assignment.type)
@@ -249,19 +250,8 @@ class GraderBaseHandler(SessionMixin, web.RequestHandler):
             shutil.rmtree(tmp_path_base)
 
     def _run_command(self, command, cwd=None, capture_output=False):
-        """Starts a sub process and runs an cmd command
-
-        Args:
-            command str: command that is getting run.
-            cwd (str, optional): states where the command is getting run. Defaults to None.
-            capture_output (bool, optional): states if output is getting saved. Defaults to False.
-
-        Raises:
-            GitError: returns appropriate git error 
-
-        Returns:
-            str: command output
-        """
+        # TODO currently there a two run_command functions,
+        #  because duplicate_release_repo does not work with the _run_command_async
         try:
             self.log.info(f"Running: {command}")
             ret = subprocess.run(shlex.split(command), check=True, cwd=cwd, capture_output=True)
@@ -274,6 +264,24 @@ class GraderBaseHandler(SessionMixin, web.RequestHandler):
             self.log.error(e)
             raise HTTPError(404, reason="File not found")
 
+    async def _run_command_async(self, command, cwd=None):
+        """Starts a sub process and runs a cmd command
+
+        Args:
+            command str: command that is getting run.
+            cwd (str, optional): states where the command is getting run. Defaults to None.
+
+        Raises:
+            GitError: returns appropriate git error 
+
+        """
+        self.log.info(f"Running: {command}")
+        ret = await asyncio.create_subprocess_shell(command,
+                                                    stdout=asyncio.subprocess.PIPE,
+                                                    stderr=asyncio.subprocess.PIPE,
+                                                    cwd=cwd)
+        await ret.wait()
+
     def write_json(self, obj) -> None:
         self.set_header("Content-Type", "application/json")
         chunk = GraderBaseHandler._serialize(obj)
@@ -310,6 +318,8 @@ class GraderBaseHandler(SessionMixin, web.RequestHandler):
             return obj
         if isinstance(obj, datetime.datetime):
             return str(obj)
+        if isinstance(obj, Decimal):
+            return float(obj)
         if isinstance(obj, Model):
             return cls._serialize(obj.to_dict())
         return None
@@ -347,6 +357,7 @@ class VersionHandler(GraderBaseHandler):
 def lti_username_convert(username):
     return username.replace("e", "")
 
+
 @register_handler(r"\/", VersionSpecifier.V1)
 class VersionHandlerV1(GraderBaseHandler):
     async def get(self):
